@@ -6,11 +6,16 @@ from dots.operation.target import Target
 
 @dataclass
 class WriteFile(Operation):
-    content: str
+    content: str  # or callable
     path: str
 
     async def apply(self, target: Target):
+        if callable(self.content):
+            content = self.content()
+        else:
+            content = self.content
+
         await target.write_file(
-            content=self.content,
+            content=content,
             path=self.path,
         )
